@@ -8,10 +8,11 @@
 
 #include <ctype.h>
 
-bool need_hexify (const u8 *buf, const int len, bool always_ascii);
+bool need_hexify (const u8 *buf, const int len, const char separator, bool always_ascii);
 void exec_hexify (const u8 *buf, const int len, u8 *out);
 
-bool is_valid_hex_char (const u8 c);
+bool is_valid_hex_string (const u8 *s, const int len);
+bool is_valid_hex_char   (const u8 c);
 
 u8 hex_convert (const u8 c);
 
@@ -19,7 +20,9 @@ u8  hex_to_u8  (const u8 hex[2]);
 u32 hex_to_u32 (const u8 hex[8]);
 u64 hex_to_u64 (const u8 hex[16]);
 
-void bin_to_hex_lower (const u32 v, u8 hex[8]);
+void u8_to_hex_lower  (const u8  v, u8 hex[2]);
+void u32_to_hex_lower (const u32 v, u8 hex[8]);
+void u64_to_hex_lower (const u64 v, u8 hex[16]);
 
 u8 int_to_base32  (const u8 c);
 u8 base32_to_int  (const u8 c);
