@@ -41,12 +41,16 @@ int tty_break(void);
 int tty_getchar(void);
 int tty_fix(void);
 
-void opencl_info                      (hashcat_ctx_t *hashcat_ctx);
-void opencl_info_compact              (hashcat_ctx_t *hashcat_ctx);
+void opencl_info                        (hashcat_ctx_t *hashcat_ctx);
+void opencl_info_compact                (hashcat_ctx_t *hashcat_ctx);
 
-void status_display_machine_readable  (hashcat_ctx_t *hashcat_ctx);
-void status_display                   (hashcat_ctx_t *hashcat_ctx);
-void status_benchmark_automate        (hashcat_ctx_t *hashcat_ctx);
-void status_benchmark                 (hashcat_ctx_t *hashcat_ctx);
+void status_progress_machine_readable   (hashcat_ctx_t *hashcat_ctx);
+void status_progress                    (hashcat_ctx_t *hashcat_ctx);
+void status_speed_machine_readable      (hashcat_ctx_t *hashcat_ctx);
+void status_speed                       (hashcat_ctx_t *hashcat_ctx);
+void status_display_machine_readable    (hashcat_ctx_t *hashcat_ctx);
+void status_display                     (hashcat_ctx_t *hashcat_ctx);
+void status_benchmark_machine_readable  (hashcat_ctx_t *hashcat_ctx);
+void status_benchmark                   (hashcat_ctx_t *hashcat_ctx);
 
 #endif // _TERMINAL_H
