@@ -85,7 +85,7 @@ int cpu_crc32 (hashcat_ctx_t *hashcat_ctx, const char *filename, u8 keytab[64])
 
   if (fd == NULL)
   {
-    event_log_error (hashcat_ctx, "%s: %s", filename, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", filename);
 
     return (-1);
   }
