@@ -86,16 +86,17 @@ int debugfile_init (hashcat_ctx_t *hashcat_ctx)
 
   debugfile_ctx->enabled = false;
 
-  if (user_options->benchmark   == true) return 0;
-  if (user_options->keyspace    == true) return 0;
-  if (user_options->left        == true) return 0;
-  if (user_options->opencl_info == true) return 0;
-  if (user_options->show        == true) return 0;
-  if (user_options->stdout_flag == true) return 0;
-  if (user_options->speed_only  == true) return 0;
-  if (user_options->usage       == true) return 0;
-  if (user_options->version     == true) return 0;
-  if (user_options->debug_mode  == 0)    return 0;
+  if (user_options->benchmark     == true) return 0;
+  if (user_options->keyspace      == true) return 0;
+  if (user_options->left          == true) return 0;
+  if (user_options->opencl_info   == true) return 0;
+  if (user_options->show          == true) return 0;
+  if (user_options->stdout_flag   == true) return 0;
+  if (user_options->speed_only    == true) return 0;
+  if (user_options->progress_only == true) return 0;
+  if (user_options->usage         == true) return 0;
+  if (user_options->version       == true) return 0;
+  if (user_options->debug_mode    == 0)    return 0;
 
   debugfile_ctx->enabled = true;
 
@@ -118,7 +119,7 @@ int debugfile_init (hashcat_ctx_t *hashcat_ctx)
     {
       fclose (fp);
 
-      event_log_error (hashcat_ctx, "%s: %s", debugfile_ctx->filename, strerror (errno));
+      event_log_error (hashcat_ctx, "%s: %m", debugfile_ctx->filename);
 
       return -1;
     }
