@@ -9,6 +9,7 @@
 #include "event.h"
 #include "dictstat.h"
 #include "locking.h"
+#include "shared.h"
 
 int sort_by_dictstat (const void *s1, const void *s2)
 {
@@ -43,17 +44,16 @@ int dictstat_init (hashcat_ctx_t *hashcat_ctx)
   if (user_options->attack_mode == ATTACK_MODE_BF) return 0;
 
   dictstat_ctx->enabled  = true;
-  dictstat_ctx->filename = (char *)       hcmalloc (HCBUFSIZ_TINY);
   dictstat_ctx->base     = (dictstat_t *) hccalloc (MAX_DICTSTAT, sizeof (dictstat_t));
   dictstat_ctx->cnt      = 0;
 
-  snprintf (dictstat_ctx->filename, HCBUFSIZ_TINY - 1, "%s/hashcat.dictstat", folder_config->profile_dir);
+  hc_asprintf (&dictstat_ctx->filename, "%s/hashcat.dictstat", folder_config->profile_dir);
 
   FILE *fp = fopen (dictstat_ctx->filename, "ab");
 
   if (fp == NULL)
   {
-    event_log_error (hashcat_ctx, "%s: %s", dictstat_ctx->filename, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", dictstat_ctx->filename);
 
     return -1;
   }
@@ -121,7 +121,7 @@ int dictstat_write (hashcat_ctx_t *hashcat_ctx)
 
   if (fp == NULL)
   {
-    event_log_error (hashcat_ctx, "%s: %s", dictstat_ctx->filename, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", dictstat_ctx->filename);
 
     return -1;
   }
@@ -130,7 +130,7 @@ int dictstat_write (hashcat_ctx_t *hashcat_ctx)
   {
     fclose (fp);
 
-    event_log_error (hashcat_ctx, "%s: %s", dictstat_ctx->filename, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", dictstat_ctx->filename);
 
     return -1;
   }
