@@ -140,7 +140,7 @@ int save_hash (hashcat_ctx_t *hashcat_ctx)
 
   if (fp == NULL)
   {
-    event_log_error (hashcat_ctx, "%s: %s", new_hashfile, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", new_hashfile);
 
     return -1;
   }
@@ -149,7 +149,7 @@ int save_hash (hashcat_ctx_t *hashcat_ctx)
   {
     fclose (fp);
 
-    event_log_error (hashcat_ctx, "%s: %s", new_hashfile, strerror (errno));
+    event_log_error (hashcat_ctx, "%s: %m", new_hashfile);
 
     return -1;
   }
@@ -215,7 +215,7 @@ int save_hash (hashcat_ctx_t *hashcat_ctx)
 
   if (rename (hashfile, old_hashfile) != 0)
   {
-    event_log_error (hashcat_ctx, "Rename file '%s' to '%s': %s", hashfile, old_hashfile, strerror (errno));
+    event_log_error (hashcat_ctx, "Rename file '%s' to '%s': %m", hashfile, old_hashfile);
 
     return -1;
   }
@@ -224,7 +224,7 @@ int save_hash (hashcat_ctx_t *hashcat_ctx)
 
   if (rename (new_hashfile, hashfile) != 0)
   {
-    event_log_error (hashcat_ctx, "Rename file '%s' to '%s': %s", new_hashfile, hashfile, strerror (errno));
+    event_log_error (hashcat_ctx, "Rename file '%s' to '%s': %m", new_hashfile, hashfile);
 
     return -1;
   }
@@ -480,7 +480,7 @@ int hashes_init_stage1 (hashcat_ctx_t *hashcat_ctx)
 
         if (hc_stat (hashes->hashfile, &st) == -1)
         {
-          event_log_error (hashcat_ctx, "%s: %s", hashes->hashfile, strerror (errno));
+          event_log_error (hashcat_ctx, "%s: %m", hashes->hashfile);
 
           return -1;
         }
@@ -502,7 +502,7 @@ int hashes_init_stage1 (hashcat_ctx_t *hashcat_ctx)
 
       if ((fp = fopen (hashfile, "rb")) == NULL)
       {
-        event_log_error (hashcat_ctx, "%s: %s", hashfile, strerror (errno));
+        event_log_error (hashcat_ctx, "%s: %m", hashfile);
 
         return -1;
       }
@@ -705,7 +705,7 @@ int hashes_init_stage1 (hashcat_ctx_t *hashcat_ctx)
 
           if (fp == NULL)
           {
-            event_log_error (hashcat_ctx, "%s: %s", hash_buf, strerror (errno));
+            event_log_error (hashcat_ctx, "%s: %m", hash_buf);
 
             return -1;
           }
@@ -813,7 +813,7 @@ int hashes_init_stage1 (hashcat_ctx_t *hashcat_ctx)
 
       if ((fp = fopen (hashfile, "rb")) == NULL)
       {
-        event_log_error (hashcat_ctx, "%s: %s", hashfile, strerror (errno));
+        event_log_error (hashcat_ctx, "%s: %m", hashfile);
 
         return -1;
       }
@@ -1342,6 +1342,13 @@ int hashes_init_stage4 (hashcat_ctx_t *hashcat_ctx)
 
   hashes->tmp_buf = tmp_buf;
 
+  // special wpa booster case
+
+  if (hashconfig->hash_mode == 2500)
+  {
+    wpa_essid_reuse (hashcat_ctx);
+  }
+
   return 0;
 }
 
