@@ -168,7 +168,7 @@ static void main_outerloop_starting (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MA
 
   status_ctx->shutdown_outer = false;
 
-  if (user_options->keyspace == false && user_options->benchmark == false && user_options->stdout_flag == false && user_options->opencl_info == false && user_options->speed_only == false)
+  if ((user_options->keyspace == false) && (user_options->stdout_flag == false) && (user_options->opencl_info == false) && (user_options->speed_only == false))
   {
     if ((user_options_extra->wordlist_mode == WL_MODE_FILE) || (user_options_extra->wordlist_mode == WL_MODE_MASK))
     {
@@ -211,7 +211,7 @@ static void main_cracker_starting (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYB
 
   if ((user_options_extra->wordlist_mode == WL_MODE_FILE) || (user_options_extra->wordlist_mode == WL_MODE_MASK))
   {
-    if ((user_options->quiet == false) && (user_options->benchmark == false) && (user_options->speed_only == false))
+    if ((user_options->quiet == false) && (user_options->speed_only == false))
     {
       event_log_info_nn (hashcat_ctx, "");
 
@@ -239,7 +239,7 @@ static void main_cracker_finished (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYB
 
   if ((user_options_extra->wordlist_mode == WL_MODE_FILE) || (user_options_extra->wordlist_mode == WL_MODE_MASK))
   {
-    if ((user_options->benchmark == false) && (user_options->speed_only == false))
+    if (user_options->speed_only == false)
     {
       clear_prompt ();
     }
@@ -247,7 +247,7 @@ static void main_cracker_finished (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYB
 
   // print final status
 
-  if ((user_options->benchmark == true) || (user_options->speed_only == true))
+  if (user_options->benchmark == true)
   {
     status_benchmark (hashcat_ctx);
 
@@ -256,6 +256,24 @@ static void main_cracker_finished (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYB
       event_log_info (hashcat_ctx, "");
     }
   }
+  else if (user_options->progress_only == true)
+  {
+    status_progress (hashcat_ctx);
+
+    if (user_options->machine_readable == false)
+    {
+      event_log_info (hashcat_ctx, "");
+    }
+  }
+  else if (user_options->speed_only == true)
+  {
+    status_speed (hashcat_ctx);
+
+    if (user_options->machine_readable == false)
+    {
+      event_log_info (hashcat_ctx, "");
+    }
+  }
   else
   {
     if (user_options->quiet == false)
@@ -497,6 +515,16 @@ static void main_weak_hash_post (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYBE_
   event_log_info_nn (hashcat_ctx, "Checked for weak hashes...");
 }
 
+static void main_weak_hash_all_cracked (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYBE_UNUSED const void *buf, MAYBE_UNUSED const size_t len)
+{
+  const user_options_t *user_options = hashcat_ctx->user_options;
+
+  if (user_options->quiet == true) return;
+
+  event_log_info (hashcat_ctx, "INFO: All hashes found during weak hashes check! You can use --show to display them.");
+  event_log_info (hashcat_ctx, "");
+}
+
 static void main_bitmap_init_pre (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYBE_UNUSED const void *buf, MAYBE_UNUSED const size_t len)
 {
   const user_options_t *user_options = hashcat_ctx->user_options;
@@ -690,6 +718,14 @@ static void main_monitor_status_refresh (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx
       send_prompt ();
     }
   }
+
+  if (user_options_extra->wordlist_mode == WL_MODE_STDIN)
+  {
+    if (user_options->quiet == false)
+    {
+      event_log_info (hashcat_ctx, "");
+    }
+  }
 }
 
 static void main_wordlist_cache_hit (MAYBE_UNUSED hashcat_ctx_t *hashcat_ctx, MAYBE_UNUSED const void *buf, MAYBE_UNUSED const size_t len)
@@ -863,6 +899,7 @@ static void event (const u32 id, hashcat_ctx_t *hashcat_ctx, const void *buf, co
     case EVENT_SET_KERNEL_POWER_FINAL:    main_set_kernel_power_final    (hashcat_ctx, buf, len); break;
     case EVENT_WEAK_HASH_POST:            main_weak_hash_post            (hashcat_ctx, buf, len); break;
     case EVENT_WEAK_HASH_PRE:             main_weak_hash_pre             (hashcat_ctx, buf, len); break;
+    case EVENT_WEAK_HASH_ALL_CRACKED:     main_weak_hash_all_cracked     (hashcat_ctx, buf, len); break;
     case EVENT_WORDLIST_CACHE_GENERATE:   main_wordlist_cache_generate   (hashcat_ctx, buf, len); break;
     case EVENT_WORDLIST_CACHE_HIT:        main_wordlist_cache_hit        (hashcat_ctx, buf, len); break;
   }
