@@ -69,7 +69,7 @@ int process_stdout (hashcat_ctx_t *hashcat_ctx, hc_device_param_t *device_param,
 
     if (fp == NULL)
     {
-      event_log_error (hashcat_ctx, "%s: %s", filename, strerror (errno));
+      event_log_error (hashcat_ctx, "%s: %m", filename);
 
       return -1;
     }
@@ -78,7 +78,7 @@ int process_stdout (hashcat_ctx_t *hashcat_ctx, hc_device_param_t *device_param,
     {
       fclose (fp);
 
-      event_log_error (hashcat_ctx, "%s: %s", filename, strerror (errno));
+      event_log_error (hashcat_ctx, "%s: %m", filename);
 
       return -1;
     }
