@@ -70,7 +70,8 @@ static const char *USAGE_BIG[] =
   "     --veracrypt-keyfiles      | File | Keyfiles used, separate with comma                   | --veracrypt-key=x.txt",
   "     --veracrypt-pim           | Num  | VeraCrypt personal iterations multiplier             | --veracrypt-pim=1000",
   " -b, --benchmark               |      | Run benchmark                                        |",
-  "     --speed-only              |      | Just return expected speed of the attack and quit    |",
+  "     --speed-only              |      | Return expected speed of the attack and quit         |",
+  "     --progress-only           |      | Return ideal progress step size and time to process  |",
   " -c, --segment-size            | Num  | Sets size in MB to cache from the wordfile to X      | -c 32",
   "     --bitmap-min              | Num  | Sets minimum bits allowed for bitmaps to X           | --bitmap-min=24",
   "     --bitmap-max              | Num  | Sets maximum bits allowed for bitmaps to X           | --bitmap-max=24",
@@ -115,8 +116,9 @@ static const char *USAGE_BIG[] =
   "      0 | MD5                                              | Raw Hash",
   "   5100 | Half MD5                                         | Raw Hash",
   "    100 | SHA1                                             | Raw Hash",
-  "  10800 | SHA-384                                          | Raw Hash",
+  "   1300 | SHA-224                                          | Raw Hash",
   "   1400 | SHA-256                                          | Raw Hash",
+  "  10800 | SHA-384                                          | Raw Hash",
   "   1700 | SHA-512                                          | Raw Hash",
   "   5000 | SHA-3(Keccak)                                    | Raw Hash",
   "  10100 | SipHash                                          | Raw Hash",
